lists.arthurdejong.org
RSS feed

python-stdnum branch master updated. 1.4-17-g8ea76ba

[Date Prev][Date Next] [Thread Prev][Thread Next]

python-stdnum branch master updated. 1.4-17-g8ea76ba



This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "python-stdnum".

The branch, master has been updated
       via  8ea76ba7ea52c3a33aae2e45d16aa41eacb6374b (commit)
       via  8028c3abe0a805577fe7bef3f0d4840264429071 (commit)
       via  70b94ee719cfe3f40aa2efe91370104a171c8677 (commit)
       via  d7cff5ddbcc3212eb9735e8a128039e5766da211 (commit)
      from  352aa8aef4b60456fba02a52460e9b8c6462b2fb (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://arthurdejong.org/git/python-stdnum/commit/?id=8ea76ba7ea52c3a33aae2e45d16aa41eacb6374b

commit 8ea76ba7ea52c3a33aae2e45d16aa41eacb6374b
Author: Arthur de Jong <arthur@arthurdejong.org>
Date:   Fri Oct 14 23:35:42 2016 +0200

    Add Australian Tax File Number
    
    Based on the implementation provided by Vincent Bastos
    <vincent@lavalab.com.au>
    
    See https://github.com/arthurdejong/python-stdnum/pull/40

diff --git a/stdnum/au/tfn.py b/stdnum/au/tfn.py
new file mode 100644
index 0000000..99b4b84
--- /dev/null
+++ b/stdnum/au/tfn.py
@@ -0,0 +1,88 @@
+# tfn.py - functions for handling Australian Tax File Numbers (TFNs)
+#
+# Copyright (C) 2016 Vincent Bastos
+# Copyright (C) 2016 Arthur de Jong
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+#
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+# 02110-1301 USA
+
+"""TFN (Australian Tax File Number).
+
+The Tax File Number (TFN) is issued by the Australian Taxation Office (ATO)
+to taxpaying individuals and organisations. A business has both a TFN and an
+Australian Business Number (ABN).
+
+The number consists of 8 (older numbers) or 9 digits and includes a check
+digit but otherwise without structure.
+
+More information:
+
+* https://en.wikipedia.org/wiki/Tax_file_number
+* https://www.ato.gov.au/Individuals/Tax-file-number/
+
+>>> validate('123 456 782')
+'123456782'
+>>> validate('999 999 999')
+Traceback (most recent call last):
+    ...
+InvalidChecksum: ...
+>>> format('123456782')
+'123 456 782'
+"""
+
+import operator
+
+from stdnum.exceptions import *
+from stdnum.util import clean
+
+
+def compact(number):
+    """Convert the number to the minimal representation. This strips the
+    number of any valid separators and removes surrounding whitespace."""
+    return clean(number, ' ').strip()
+
+
+def checksum(number):
+    """Calculate the checksum."""
+    weights = (1, 4, 3, 7, 5, 8, 6, 9, 10)
+    return sum(w * int(n) for w, n in zip(weights, number)) % 11
+
+
+def validate(number):
+    """Checks to see if the number provided is a valid TFN. This checks the
+    length, formatting and check digit."""
+    number = compact(number)
+    if not number.isdigit():
+        raise InvalidFormat()
+    if len(number) not in (8, 9):
+        raise InvalidLength()
+    if checksum(number) != 0:
+        raise InvalidChecksum()
+    return number
+
+
+def is_valid(number):
+    """Checks to see if the number provided is a valid TFN. This checks the
+    length, formatting and check digit."""
+    try:
+        return bool(validate(number))
+    except ValidationError:
+        return False
+
+
+def format(number):
+    """Reformat the passed number to the standard format."""
+    number = compact(number)
+    return ' '.join((number[0:3], number[3:6], number[6:]))
diff --git a/tests/test_au_tfn.doctest b/tests/test_au_tfn.doctest
new file mode 100644
index 0000000..1dddcae
--- /dev/null
+++ b/tests/test_au_tfn.doctest
@@ -0,0 +1,42 @@
+test_au_tfn.doctest - more detailed doctests for the stdnum.au.tfn module
+
+Copyright (C) 2016 Arthur de Jong
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA
+
+
+This file contains more detailed doctests for the stdnum.au.tfn module. It
+tries to validate a number of numbers that have been found online.
+
+>>> from stdnum.au import tfn
+>>> from stdnum.exceptions import *
+
+
+These have been found online and should all be valid numbers.
+
+>>> numbers = '''
+...
+... 112474082
+... 459599230
+... 565051603
+... 812 239 321
+... 865414088
+... 876 543 210
+... 907974668
+...
+... '''
+>>> [x for x in numbers.splitlines() if x and not tfn.is_valid(x)]
+[]

http://arthurdejong.org/git/python-stdnum/commit/?id=8028c3abe0a805577fe7bef3f0d4840264429071

commit 8028c3abe0a805577fe7bef3f0d4840264429071
Author: Arthur de Jong <arthur@arthurdejong.org>
Date:   Fri Oct 14 18:33:05 2016 +0200

    Add Australian Company Number
    
    Based on the implementation provided by Vincent Bastos
    <vincent@lavalab.com.au>
    
    See https://github.com/arthurdejong/python-stdnum/pull/40

diff --git a/stdnum/au/acn.py b/stdnum/au/acn.py
new file mode 100644
index 0000000..ed99d3d
--- /dev/null
+++ b/stdnum/au/acn.py
@@ -0,0 +1,91 @@
+# acn.py - functions for handling Australian Company Numbers (ACNs)
+#
+# Copyright (C) 2016 Vincent Bastos
+# Copyright (C) 2016 Arthur de Jong
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+#
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+# 02110-1301 USA
+
+"""ACN (Australian Company Number).
+
+The Australian Company Number (ACN) is a company identifier issued by the
+Australian Securities and Investments Commission.
+
+More information:
+
+* https://en.wikipedia.org/wiki/Australian_Company_Number
+
+>>> validate('004 085 616')
+'004085616'
+>>> validate('010 499 966')
+'010499966'
+>>> validate('999 999 999')
+Traceback (most recent call last):
+    ...
+InvalidChecksum: ...
+>>> format('004085616')
+'004 085 616'
+>>> to_abn('002 724 334')
+'43002724334'
+"""
+
+from stdnum.exceptions import *
+from stdnum.util import clean
+
+
+def compact(number):
+    """Convert the number to the minimal representation. This strips the
+    number of any valid separators and removes surrounding whitespace."""
+    return clean(number, ' ').strip()
+
+
+def calc_check_digit(number):
+    """Calculate the checksum."""
+    return str((sum(int(n) * (i - 8) for i, n in enumerate(number))) % 10)
+
+
+def validate(number):
+    """Checks to see if the number provided is a valid ACN. This checks the
+    length, formatting and check digit."""
+    number = compact(number)
+    if not number.isdigit():
+        raise InvalidFormat()
+    if len(number) != 9:
+        raise InvalidLength()
+    if calc_check_digit(number) != number[-1]:
+        raise InvalidChecksum()
+    return number
+
+
+def is_valid(number):
+    """Checks to see if the number provided is a valid ACN. This checks the
+    length, formatting and check digit."""
+    try:
+        return bool(validate(number))
+    except ValidationError:
+        return False
+
+
+def format(number):
+    """Reformat the passed number to the standard format."""
+    number = compact(number)
+    return ' '.join((number[0:3], number[3:6], number[6:]))
+
+
+def to_abn(number):
+    """Convert the number to an Australian Business Number (ABN)."""
+    from stdnum.au import abn
+    number = compact(number)
+    return abn.calc_check_digits(number) + number
diff --git a/tests/test_au_acn.doctest b/tests/test_au_acn.doctest
new file mode 100644
index 0000000..da7bd4a
--- /dev/null
+++ b/tests/test_au_acn.doctest
@@ -0,0 +1,125 @@
+test_au_acn.doctest - more detailed doctests for the stdnum.au.acn module
+
+Copyright (C) 2016 Arthur de Jong
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA
+
+
+This file contains more detailed doctests for the stdnum.au.acn module. It
+tries to validate a number of numbers that have been found online.
+
+>>> from stdnum.au import acn, abn
+>>> from stdnum.exceptions import *
+
+
+These have been found online and should all be valid numbers.
+
+>>> numbers = '''
+...
+... 000 024 733
+... 001 002 731
+... 001 976 272
+... 002 724 334
+... 002 955 722
+... 003 855 561
+... 004 071 854
+... 004 235 063
+... 004 394 763
+... 005 957 004
+... 007 433 623
+... 050 539 350
+... 055 980 204
+... 082 930 916
+... 088 952 023
+... 093 966 888 
+... 099503456
+... 104 045 089
+... 104 128 001
+... 112 045 002
+... 116 306 453
+... 125 295 712 
+... 135 427 075 
+... 141 800 357
+... 143477632
+...
+... 000 000 019
+... 000 250 000
+... 000 500 005
+... 000 750 005
+... 001 000 004
+... 001 250 004
+... 001 500 009
+... 001 749 999
+... 001 999 999
+... 002 249 998
+... 002 499 998
+... 002 749 993
+... 002 999 993
+... 003 249 992
+... 003 499 992
+... 003 749 988
+... 003 999 988
+... 004 249 987
+... 004 499 987
+... 004 749 982
+... 004 999 982
+... 005 249 981
+... 005 499 981
+... 005 749 986
+... 005 999 977
+... 006 249 976
+... 006 499 976
+... 006 749 980
+... 006 999 980
+... 007 249 989
+... 007 499 989
+... 007 749 975
+... 007 999 975
+... 008 249 974
+... 008 499 974
+... 008 749 979
+... 008 999 979
+... 009 249 969
+... 009 499 969
+... 009 749 964
+... 009 999 964
+... 010 249 966
+... 010 499 966
+... 010 749 961
+...
+... '''
+>>> [x for x in numbers.splitlines() if x and not acn.is_valid(x)]
+[]
+
+
+These numbers have been found in combination with an existing ABN.
+
+>>> numbers = '''
+...
+... 000 024 733 / 79 000 024 733
+... 002 724 334 / 43002724334
+... 004 071 854 / 56 004 071 854
+... 004 235 063 / 63 004 235 063
+... 004 394 763 / 74 004 394 763
+... 055 980 204 / 31 055 980 204
+... 104 045 089 / 97 104 045 089
+... 112 045 002 / 19 112 045 002
+... 143477632   / 28143477632
+...
+... '''
+>>> lines = (l.split('/') for l in numbers.splitlines() if l)
+>>> [(x, y) for x, y in lines if acn.to_abn(x) != abn.compact(y)]
+[]

http://arthurdejong.org/git/python-stdnum/commit/?id=70b94ee719cfe3f40aa2efe91370104a171c8677

commit 70b94ee719cfe3f40aa2efe91370104a171c8677
Author: Arthur de Jong <arthur@arthurdejong.org>
Date:   Fri Oct 14 15:42:55 2016 +0200

    Add Australian Business Number
    
    Based on the implementation provided by Vincent Bastos
    <vincent@lavalab.com.au>
    
    See https://github.com/arthurdejong/python-stdnum/pull/40

diff --git a/stdnum/au/__init__.py b/stdnum/au/__init__.py
new file mode 100644
index 0000000..bcf9b0b
--- /dev/null
+++ b/stdnum/au/__init__.py
@@ -0,0 +1,21 @@
+# __init__.py - collection of Australian numbers
+# coding: utf-8
+#
+# Copyright (C) 2016 Vincent Bastos
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+#
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+# 02110-1301 USA
+
+"""Collection of Australian numbers."""
diff --git a/stdnum/au/abn.py b/stdnum/au/abn.py
new file mode 100644
index 0000000..ba69557
--- /dev/null
+++ b/stdnum/au/abn.py
@@ -0,0 +1,85 @@
+# abn.py - functions for handling Australian Business Numbers (ABNs)
+#
+# Copyright (C) 2016 Vincent Bastos
+# Copyright (C) 2016 Arthur de Jong
+#
+# This library is free software; you can redistribute it and/or
+# modify it under the terms of the GNU Lesser General Public
+# License as published by the Free Software Foundation; either
+# version 2.1 of the License, or (at your option) any later version.
+#
+# This library is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+# Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public
+# License along with this library; if not, write to the Free Software
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+# 02110-1301 USA
+
+"""ABN (Australian Business Number).
+
+The Australian Business Number (ABN) is an identifier issued to entities
+registered in the Australian Business Register (ABR). The number consists of
+11 digits of which the first two are check digits.
+
+More information:
+
+* https://en.wikipedia.org/wiki/Australian_Business_Number
+* https://abr.business.gov.au/
+
+>>> validate('83 914 571 673')
+'83914571673'
+>>> validate('99 999 999 999')
+Traceback (most recent call last):
+    ...
+InvalidChecksum: ...
+>>> format('51824753556')
+'51 824 753 556'
+"""
+
+from stdnum.exceptions import *
+from stdnum.util import clean
+
+
+def compact(number):
+    """Convert the number to the minimal representation. This strips the
+    number of any valid separators and removes surrounding whitespace."""
+    return clean(number, ' ').strip()
+
+
+def calc_check_digits(number):
+    """Calculate the check digits that should be prepended to make the number
+    valid."""
+    weights = (3, 5, 7, 9, 11, 13, 15, 17, 19)
+    s = sum(-w * int(n) for w, n in zip(weights, number))
+    return str(11 + (s - 1) % 89)
+
+
+def validate(number):
+    """Checks to see if the number provided is a valid ABN. This checks the
+    length, formatting and check digit."""
+    number = compact(number)
+    if not number.isdigit():
+        raise InvalidFormat()
+    if len(number) != 11:
+        raise InvalidLength()
+    if calc_check_digits(number[2:]) != number[:2]:
+        raise InvalidChecksum()
+    return number
+
+
+def is_valid(number):
+    """Checks to see if the number provided is a valid ABN. This checks the
+    length, formatting and check digit."""
+    try:
+        return bool(validate(number))
+    except ValidationError:
+        return False
+
+
+def format(number):
+    """Reformat the passed number to the standard format."""
+    number = compact(number)
+    return ' '.join((number[0:2], number[2:5], number[5:8], number[8:]))
diff --git a/tests/test_au_abn.doctest b/tests/test_au_abn.doctest
new file mode 100644
index 0000000..079b0e3
--- /dev/null
+++ b/tests/test_au_abn.doctest
@@ -0,0 +1,136 @@
+test_au_abn.doctest - more detailed doctests for the stdnum.au.abn module
+
+Copyright (C) 2016 Arthur de Jong
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+02110-1301 USA
+
+
+This file contains more detailed doctests for the stdnum.au.abn module. It
+tries to validate a number of numbers that have been found online.
+
+>>> from stdnum.au import abn
+>>> from stdnum.exceptions import *
+
+
+These have been found online and should all be valid numbers.
+
+>>> numbers = '''
+...
+... 11574456001
+... 12 123 552 732
+... 12197960056
+... 14 007 145 637
+... 14 085 537 097
+... 15 071 884 994
+... 16 050 539 350
+... 16 875 959 817
+... 16207643640
+... 17 088 952 023 
+... 17 091 664 318
+... 17798019840
+... 18657363620
+... 18986035694
+... 19406270520
+... 20 080 574 616
+... 21 006 741 420
+... 211 082 588 59
+... 21276698420
+... 22752397988
+... 25 009 256 179
+... 25 078 164 020
+... 26 128 975 842
+... 27146513745
+... 29 176 219 543
+... 30194533815
+... 30319635949
+... 30753140115
+... 32510077067
+... 32967065962
+... 34180019054
+... 35 061 659 185
+... 35367869361
+... 36562063587
+... 38032136826
+... 38689369989
+... 42350020583
+... 42793074259
+... 43 002 724 334
+... 45138393975
+... 45686492545
+... 46 003 855 561
+... 46 003 855 561 
+... 46065060376
+... 46080667721
+... 46241363405
+... 48110267900
+... 49046814670
+... 50 001 065 096
+... 50785233431
+... 51 824 753 556
+... 51120335948
+... 51424722884
+... 51974674048
+... 52 007 061 930
+... 54159269665
+... 55344832020
+... 55593511022
+... 57 064 001 270
+... 57356639841
+... 58437726834
+... 60431599619
+... 61173792360
+... 61483329243
+... 62128948118
+... 62361423248
+... 62826560160
+... 66 098 752 319
+... 66870124640
+... 68515519306
+... 69629520833
+... 73401973717
+... 73420076995
+... 74756347129
+... 74823923971
+... 75 091 431 202
+... 79772126259
+... 81 633 873 422
+... 83562801946
+... 84 002 705 224
+... 84598062158
+... 84696968277
+... 84771313085
+... 85 192 178 954
+... 85573270719
+... 86760778045
+... 87252821098
+... 88 775 098 848
+... 88278681363
+... 90 006 091 774
+... 90399103769
+... 91 010 334 915
+... 91044249923
+... 91957581192
+... 92 104 128 001
+... 93915085021
+... 96196152632
+... 97522448851
+... 98 116 306 453
+... 98977939326
+... 99870624871
+...
+... '''
+>>> [x for x in numbers.splitlines() if x and not abn.is_valid(x)]
+[]

http://arthurdejong.org/git/python-stdnum/commit/?id=d7cff5ddbcc3212eb9735e8a128039e5766da211

commit d7cff5ddbcc3212eb9735e8a128039e5766da211
Author: Arthur de Jong <arthur@arthurdejong.org>
Date:   Fri Oct 14 11:17:38 2016 +0200

    Provide businessid as an alias
    
    The Belgian company number or enterprise number (ondernemingsnummer) is
    the new name for what was previously the VAT number.

diff --git a/stdnum/be/__init__.py b/stdnum/be/__init__.py
index dd18378..5295496 100644
--- a/stdnum/be/__init__.py
+++ b/stdnum/be/__init__.py
@@ -1,7 +1,7 @@
 # __init__.py - collection of Belgian numbers
 # coding: utf-8
 #
-# Copyright (C) 2012 Arthur de Jong
+# Copyright (C) 2012-2016 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -19,3 +19,6 @@
 # 02110-1301 USA
 
 """Collection of Belgian numbers."""
+
+# provide businessid as an alias
+from stdnum.be import vat as businessid
diff --git a/stdnum/be/vat.py b/stdnum/be/vat.py
index 5bffa3f..39a3335 100644
--- a/stdnum/be/vat.py
+++ b/stdnum/be/vat.py
@@ -1,6 +1,6 @@
 # vat.py - functions for handling Belgian VAT numbers
 #
-# Copyright (C) 2012, 2013 Arthur de Jong
+# Copyright (C) 2012-2016 Arthur de Jong
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,7 +17,11 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 # 02110-1301 USA
 
-"""BTW, TVA, NWSt (Belgian VAT number).
+"""BTW, TVA, NWSt, ondernemingsnummer (Belgian enterprise number).
+
+The enterprise number (ondernemingsnummer) is a unique identifier of
+companies within the Belgian administrative services. It was previously
+the VAT ID number. The number consists of 10 digits.
 
 >>> compact('BE403019261')
 '0403019261'

-----------------------------------------------------------------------

Summary of changes:
 stdnum/{ch => au}/__init__.py                      |   6 +-
 stdnum/{no/orgnr.py => au/abn.py}                  |  54 ++++----
 stdnum/{no/orgnr.py => au/acn.py}                  |  56 +++++----
 stdnum/{no/orgnr.py => au/tfn.py}                  |  49 +++++---
 stdnum/be/__init__.py                              |   5 +-
 stdnum/be/vat.py                                   |   8 +-
 tests/test_au_abn.doctest                          | 136 +++++++++++++++++++++
 tests/test_au_acn.doctest                          | 125 +++++++++++++++++++
 .../{test_fr_siren.doctest => test_au_tfn.doctest} |  29 ++---
 9 files changed, 379 insertions(+), 89 deletions(-)
 copy stdnum/{ch => au}/__init__.py (85%)
 copy stdnum/{no/orgnr.py => au/abn.py} (54%)
 copy stdnum/{no/orgnr.py => au/acn.py} (56%)
 copy stdnum/{no/orgnr.py => au/tfn.py} (60%)
 create mode 100644 tests/test_au_abn.doctest
 create mode 100644 tests/test_au_acn.doctest
 copy tests/{test_fr_siren.doctest => test_au_tfn.doctest} (66%)


hooks/post-receive
-- 
python-stdnum
-- 
To unsubscribe send an email to
python-stdnum-commits-unsubscribe@lists.arthurdejong.org or see
https://lists.arthurdejong.org/python-stdnum-commits/